@@ -1,44 +1,18 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef INETMAPI_H
@@ -50,12 +24,20 @@
 #include <mapix.h>
 #include <mapidefs.h>
 #include <vector>
-#include "options.h"
+#include <inetmapi/options.h>
 
 class ECLogger;
 
+#ifdef _WIN32
+# ifdef INETMAPI_EXPORTS
+#  define INETMAPI_API __declspec(dllexport)
+# else
+#  define INETMAPI_API __declspec(dllimport)
+# endif
+#else
 /* we do not need this on linux */
 # define INETMAPI_API
+#endif
 
 typedef struct _sFailedRecip {
 	std::string strRecipEmail;
@@ -73,7 +55,8 @@ protected:
 	std::wstring error;
 	int smtpresult;
 
-	std::vector<sFailedRecip> lstFailedRecipients;
+	std::vector<sFailedRecip> mTemporaryFailedRecipients;
+	std::vector<sFailedRecip> mPermanentFailedRecipients;
 
 	ECLogger *lpLogger;
 
@@ -87,11 +70,8 @@ public:
 	virtual void setError(const std::string &newError);
 	virtual bool haveError();
 
-	virtual const unsigned int getRecipientErrorCount() const;
-	virtual const unsigned int getRecipientErrorSMTPCode(unsigned int offset) const;
-	virtual const std::string getRecipientErrorText(unsigned int offset) const;
-	virtual const std::wstring getRecipientErrorDisplayName(unsigned int offset) const;
-	virtual const std::string getRecipientErrorEmailAddress(unsigned int offset) const;
+	virtual const std::vector<sFailedRecip> &getPermanentFailedRecipients(void) const;
+	virtual const std::vector<sFailedRecip> &getTemporaryFailedRecipients(void) const;
 };
 
 bool ValidateCharset(const char *charset);
