@@ -1,83 +1,34 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef COMMONUTIL_H
 #define COMMONUTIL_H
 
-#include "zcdefs.h"
+#include <zarafa/zcdefs.h>
 #include <mapidefs.h>
 #include <mapix.h>
 #include <string>
-#include "ECTags.h"
-#include "charset/utf32string.h"
+#include <zarafa/ECTags.h>
 #include <list>
 
-#include "ustringutil.h"
+#include <zarafa/ustringutil.h>
 
 class ECLogger;
 
-// Newmail Notify columns
-const static SizedSPropTagArray(4, sPropNewMailColumns) =
-{
-	4,
-	{
-		PR_ENTRYID,
-		PR_PARENT_ENTRYID,
-		PR_MESSAGE_CLASS_A,
-		PR_MESSAGE_FLAGS
-	}
-};
-
-// Indexes of the sPropNewMailColumns property array
-enum
-{
-	NEWMAIL_ENTRYID,		// Array Indexes
-	NEWMAIL_PARENT_ENTRYID,
-	NEWMAIL_MESSAGE_CLASS,
-	NEWMAIL_MESSAGE_FLAGS,
-	NUM_NEWMAIL_PROPS		// Array size
-};
-
 // Version of GetClientVersion
 #define CLIENT_VERSION_OLK2000			9
 #define CLIENT_VERSION_OLK2002			10
@@ -87,10 +38,8 @@ enum
 #define CLIENT_VERSION_LATEST			CLIENT_VERSION_OLK2010 /* UPDATE ME */
 
 /* darn, no sane place because of depend include on mapidefs.h */
-bool operator ==(SBinary a, SBinary b);
-bool operator <(SBinary a, SBinary b);
-
-#define CLIENT_ADMIN_SOCKET "file:///var/run/zarafa"
+bool operator ==(const SBinary &a, const SBinary &b);
+bool operator <(const SBinary &a, const SBinary &b);
 
 const char *GetServerUnixSocket(const char *szPreferred = NULL);
 std::string GetServerFQDN();
@@ -190,7 +139,7 @@ HRESULT HrGetGAB(LPADRBOOK lpAddrBook, LPABCONT *lppGAB);
  * printf("%X %X\n", PROP_RECURRING, PROP_START);
  *
  */
-class ECPropMapEntry _final {
+class ECPropMapEntry _zcp_final {
 public:
     ECPropMapEntry(GUID guid, ULONG ulId);
     ECPropMapEntry(GUID guid, const char *strName);
@@ -203,7 +152,7 @@ private:
     GUID m_sGuid;
 };
 
-class ECPropMap _final {
+class ECPropMap _zcp_final {
 public:
     ECPropMap();
     void AddProp(ULONG *lpId, ULONG ulType, ECPropMapEntry entry);
