@@ -1,59 +1,36 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef ECCHANNEL_H
 #define ECCHANNEL_H
 
-#include "zcdefs.h"
+#include <zarafa/zcdefs.h>
 #include <cstdio>
 #include <iostream>
+#include <sys/socket.h>
 #include <openssl/ssl.h>
 #include <openssl/err.h>
 
 #include <string>
 
-#include "ECConfig.h"
-#include "ECLogger.h"
+#include <zarafa/ECConfig.h>
+#include <zarafa/ECLogger.h>
+
+struct sockaddr;
 
 // ECChannel is the communication channel with the other side. Initially, it is
 // a simple way to read/write full lines of data. The reason why we specify
@@ -62,7 +39,7 @@
 // this ensures that the ECChannel class is responsible for reading, writing
 // and culling newline characters.
 
-class ECChannel _final {
+class ECChannel _zcp_final {
 public:
 	ECChannel(int socket);
 	~ECChannel();
@@ -81,8 +58,9 @@ public:
 
 	HRESULT HrSelect(int seconds);
 
-	void SetIPAddress(char *szIPAddress);
-	const std::string& GetIPAddress() const;
+	void SetIPAddress(const struct sockaddr *, size_t);
+	const char *peer_addr(void) const;
+	int peer_is_local(void) const;
 		
 	bool UsingSsl();
 	bool sslctx();
@@ -94,7 +72,9 @@ private:
 	int fd;
 	SSL *lpSSL;
 	static SSL_CTX *lpCTX;
-	std::string strIP;
+	char peer_atxt[256+16];
+	struct sockaddr_storage peer_sockaddr;
+	socklen_t peer_salen;
 
 	char *fd_gets(char *buf, int *lpulLen);
 	char *SSL_gets(char *buf, int *lpulLen);
@@ -102,8 +82,16 @@ private:
 
 /* helpers to open socket */
 HRESULT HrListen(ECLogger *lpLogger, const char *szPath, int *lpulListenSocket);
-HRESULT HrListen(ECLogger *lpLogger, const char *szBind, int ulPort, int *lpulListenSocket);
+HRESULT HrListen(ECLogger *lpLogger, const char *szBind, uint16_t ulPort, int *lpulListenSocket);
 /* accept data on connection */
 HRESULT HrAccept(ECLogger *lpLogger, int ulListenFD, ECChannel **lppChannel);
 
+extern "C" {
+
+extern int zcp_bindtodevice(ECLogger *log, int fd, const char *iface);
+extern int zcp_peeraddr_is_local(const struct sockaddr *, socklen_t);
+extern int zcp_peerfd_is_local(int);
+
+}
+
 #endif
