@@ -1,47 +1,21 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
-#include "platform.h"
+#include <zarafa/platform.h>
 
 #ifndef ECDEFS_H
 #define ECDEFS_H
@@ -94,7 +68,7 @@
 #define OBJECTCLASS_TYPE(__class) \
 	( (objecttype_t)(((__class) >> 16) & 0xffff) )
 #define OBJECTCLASS_ISTYPE(__class) \
-	( (((__class) & 0xffff) == 0) && (((__class) >> 16) != 0) )
+	( ((__class) & 0xffff) == 0 && ((__class) >> 16) != 0)
 #define OBJECTCLASS_FIELD_COMPARE(__left, __right) \
 	( !(__left) || !(__right) || (__left) == (__right) )
 #define OBJECTCLASS_COMPARE(__left, __right) \
@@ -159,13 +133,13 @@ typedef struct _sECEntryId
 {
 	unsigned int	cb;
 	unsigned char*	lpb;
-} ECENTRYID, *LPECENTRYID;
+} ECENTRYID;
 
 typedef struct _sECServerNameList
 {
 	unsigned int	cServers;
 	LPTSTR*			lpszaServer;
-} ECSVRNAMELIST, *LPECSVRNAMELIST;
+} ECSVRNAMELIST;
 
 typedef struct _sPropmapEntry {
 	unsigned int	ulPropId;
@@ -201,7 +175,7 @@ typedef struct _sECUser {
 	SPROPMAP		sPropmap;		// Extra anonymous properties for addressbook
 	MVPROPMAP		sMVPropmap;		// Extra anonymous MV properties for addressbook
 	ECENTRYID		sUserId;
-} ECUSER, *LPECUSER;
+} ECUSER;
 
 typedef struct _sECGroup {
 	LPTSTR			lpszGroupname; // groupname@companyname
@@ -211,7 +185,7 @@ typedef struct _sECGroup {
 	unsigned int	ulIsABHidden;	// Is group hidden from address book
 	SPROPMAP		sPropmap;		// Extra anonymous properties for addressbook
 	MVPROPMAP		sMVPropmap;		// Extra anonymous MV properties for addressbook
-}ECGROUP, *LPECGROUP;
+} ECGROUP;
 
 typedef struct _sECCompany {
 	ECENTRYID		sAdministrator; // userid of the administrator
@@ -221,7 +195,7 @@ typedef struct _sECCompany {
 	unsigned int	ulIsABHidden;	// Is company hidden from address book
 	SPROPMAP		sPropmap;		// Extra anonymous properties for addressbook
 	MVPROPMAP		sMVPropmap;		// Extra anonymous MV properties for addressbook
-} ECCOMPANY, *LPECCOMPANY;
+} ECCOMPANY;
 
 
 typedef struct _sUserClientUpdateStatus {
@@ -231,7 +205,7 @@ typedef struct _sUserClientUpdateStatus {
 	LPTSTR			lpszLatestversion;
 	LPTSTR			lpszComputername;
 	unsigned int 	ulStatus;
-}ECUSERCLIENTUPDATESTATUS, *LPECUSERCLIENTUPDATESTATUS;
+} ECUSERCLIENTUPDATESTATUS;
 
 #define UPDATE_STATUS_UNKNOWN	0
 #define UPDATE_STATUS_SUCCESS   1
@@ -243,7 +217,7 @@ typedef struct _sECPermission {
 	unsigned int	ulRights;
 	unsigned int	ulState;
 	ECENTRYID		sUserId;
-}ECPERMISSION, *LPECPERMISSION;
+} ECPERMISSION;
 
 typedef struct _sECQuota {
 	bool			bUseDefaultQuota;
@@ -251,12 +225,12 @@ typedef struct _sECQuota {
 	int64_t		llWarnSize;
 	int64_t		llSoftSize;
 	int64_t		llHardSize;
-}ECQUOTA, *LPECQUOTA;
+} ECQUOTA;
 
 typedef struct _sECQuotaStatus {
 	int64_t		llStoreSize;
 	eQuotaStatus	quotaStatus;
-}ECQUOTASTATUS, *LPECQUOTASTATUS;
+} ECQUOTASTATUS;
 
 typedef struct _sECServer {
 	LPTSTR	lpszName;
@@ -265,12 +239,12 @@ typedef struct _sECServer {
 	LPTSTR	lpszSslPath;
 	LPTSTR	lpszPreferedPath;
 	ULONG	ulFlags;
-}ECSERVER, *LPECSERVER;
+} ECSERVER;
 
 typedef struct _sECServerList {
 	unsigned int	cServers;
-	LPECSERVER		lpsaServer;
-}ECSERVERLIST, *LPECSERVERLIST;
+	ECSERVER *lpsaServer;
+} ECSERVERLIST;
 
 // Flags for ns__submitMessage
 #define EC_SUBMIT_LOCAL			0x00000000
