@@ -1,44 +1,18 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef ECThreadPool_INCLUDED
@@ -47,8 +21,13 @@
 #include <pthread.h>
 #include <set>
 #include <list>
-#include "zcdefs.h"
+#include <zarafa/zcdefs.h>
 
+#ifdef WIN32
+static inline bool operator<(const pthread_t &lhs, const pthread_t &rhs) {
+	return lhs.p < rhs.p;
+}
+#endif
 
 class ECTask;
 
@@ -57,7 +36,7 @@ class ECTask;
  * The amount of workers can be modified at run time, but is not automatically
  * adjusted based on the task queue length or age.
  */
-class ECThreadPool _final {
+class ECThreadPool _zcp_final {
 private:	// types
 	struct STaskInfo {
 		ECTask			*lpTask;
@@ -171,7 +150,7 @@ public:
 	
 public:
 	virtual ~ECWaitableTask();
-	virtual void execute(void) _override;
+	virtual void execute(void) _zcp_override;
 	
 	bool done() const;
 	bool wait(unsigned timeout = WAIT_INFINITE, unsigned waitMask = Done) const;
@@ -200,7 +179,7 @@ inline bool ECWaitableTask::done() const {
  * To call a function with more than one argument boost::bind can be used.
  */
 template<typename _Rt, typename _Fn, typename _At>
-class ECDeferredFunc _final : public ECWaitableTask
+class ECDeferredFunc _zcp_final : public ECWaitableTask
 {
 public:
 	/**
@@ -211,7 +190,7 @@ public:
 	ECDeferredFunc(_Fn fn, const _At &arg) : m_fn(fn), m_arg(arg)
 	{ }
 	
-	virtual void run(void) _override
+	virtual void run(void) _zcp_override
 	{
 		m_result = m_fn(m_arg);
 	}
