@@ -1,50 +1,24 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef convert_INCLUDED
 #define convert_INCLUDED
 
-#include "zcdefs.h"
+#include <zarafa/zcdefs.h>
 #include <map>
 #include <set>
 #include <list>
@@ -53,7 +27,7 @@
 #include <typeinfo>
 
 #include <iconv.h>
-#include "traits.h"
+#include <zarafa/charset/traits.h>
 
 /**
  * @brief	Exception class
@@ -78,7 +52,7 @@ private:
 /**
  * @brief	Unknown charset
  */
-class unknown_charset_exception _final : public convert_exception {
+class unknown_charset_exception _zcp_final : public convert_exception {
 public:
 	unknown_charset_exception(const std::string &message);
 };
@@ -86,7 +60,7 @@ public:
 /**
  * @brief	Illegal sequence
  */
-class illegal_sequence_exception _final : public convert_exception {
+class illegal_sequence_exception _zcp_final : public convert_exception {
 public:
 	illegal_sequence_exception(const std::string &message);
 };
@@ -132,7 +106,7 @@ namespace details {
 		 * @param[in] lpBuf		Pointer to the data to be appended.
 		 * @param[in] cbBuf		Size of the data to be appended in bytes.
 		 */
-		virtual void append(const char *lpBuf, size_t cbBuf) throw() = 0;
+		virtual void append(const char *lpBuf, size_t cbBuf) = 0;
 		
 	private:
 		iconv_t	m_cd;
@@ -149,7 +123,7 @@ namespace details {
 	 * @brief	Default converter from one charset to another with string types.
 	 */
 	template <typename _To_Type, typename _From_Type>
-	class iconv_context _final : public iconv_context_base
+	class iconv_context _zcp_final : public iconv_context_base
 	{
 	public:
 		/**
@@ -208,7 +182,7 @@ namespace details {
 		}
 		
 	private:
-		void append(const char *lpBuf, size_t cbBuf) throw() _override {
+		void append(const char *lpBuf, size_t cbBuf) _zcp_override {
 			m_to.append(reinterpret_cast<typename _To_Type::const_pointer>(lpBuf), cbBuf / sizeof(typename _To_Type::value_type));
 		}
 
@@ -225,7 +199,7 @@ namespace details {
 	 * that case the string is merely copied.
 	 */
 	template <typename _Type>
-	class convert_helper _final {
+	class convert_helper _zcp_final {
 	public:
 		/**
 		 * @brief Converts a string to a string with the same charset.
@@ -234,7 +208,7 @@ namespace details {
 		 * @param[in] _from		The string to be converted.
 		 * @return				The converted string.
 		 */
-		static _Type convert(const _Type &_from) throw() { return _from; }
+		static _Type convert(const _Type &_from) { return _from; }
 
 		/**
 		 * @brief Converts a string to a string with a different charset.
@@ -329,12 +303,12 @@ inline _To_Type convert_to(const char *tocode, const _From_Type &_from, size_t c
  * same context. This basically means that the details::iconv_context classes can
  * be reused, removing the need to recreate them for each conversion.
  */
-class convert_context _final {
+class convert_context _zcp_final {
 public:
 	/**
 	 * @brief Constructor.
 	 */
-	convert_context() throw();
+	convert_context();
 	
 	/**
 	 * @brief Destructor.
@@ -395,12 +369,12 @@ private:
 	 * identical. In that case the string is merely copied.
 	 */
 	template <typename _Type>
-	class helper _final {
+	class helper _zcp_final {
 	public:
 		/**
 		 * @brief Constructor.
 		 */
-		helper(convert_context &context) throw()
+		helper(convert_context &context)
 			: m_context(context) 
 		{}
 
@@ -411,7 +385,7 @@ private:
 		 * @param[in] _from		The string to be converted.
 		 * @return				The converted string.
 		 */
-		_Type convert(const _Type &_from) throw() {
+		_Type convert(const _Type &_from) {
 			return _from;
 		}
 
@@ -474,14 +448,14 @@ private:
 	 * the caller will end up with a pointer to non-existing data.
 	 */
 	template <typename _Type>
-	class helper<_Type *> _final {
+	class helper<_Type *> _zcp_final {
 	public:
 		typedef std::basic_string<_Type> string_type;
 	
 		/**
 		 * @brief Constructor.
 		 */
-		helper(convert_context &context) throw()
+		helper(convert_context &context)
 			: m_context(context) 
 			, m_helper(context)
 		{}
@@ -578,9 +552,9 @@ private:
 	/**
 	 * @brief Sort predicate for the context_map;
 	 */
-	class context_predicate _final {
+	class context_predicate _zcp_final {
 	public:
-		bool operator()(const context_key &lhs, const context_key &rhs) const throw() {
+		bool operator()(const context_key &lhs, const context_key &rhs) const {
 			int r = strcmp(lhs.fromtype, rhs.fromtype);
 			if (r != 0)
 				return (r < 0);
@@ -782,7 +756,7 @@ namespace details {
  * @return				HRESULT.
  */
 template <typename _To_Type, typename _From_Type>
-HRESULT TryConvert(const _From_Type &_from, _To_Type &_to) throw() {
+HRESULT TryConvert(const _From_Type &_from, _To_Type &_to) {
 	try {
 		_to = convert_to<_To_Type>(_from);
 		return hrSuccess;
@@ -803,7 +777,7 @@ HRESULT TryConvert(const _From_Type &_from, _To_Type &_to) throw() {
  * @return				HRESULT.
  */
 template <typename _To_Type, typename _From_Type>
-HRESULT TryConvert(const _From_Type &_from, size_t cbBytes, const char *fromcode, _To_Type &_to) throw() {
+HRESULT TryConvert(const _From_Type &_from, size_t cbBytes, const char *fromcode, _To_Type &_to) {
 	try {
 		_to = convert_to<_To_Type>(_from, cbBytes, fromcode);
 		return hrSuccess;
@@ -823,7 +797,7 @@ HRESULT TryConvert(const _From_Type &_from, size_t cbBytes, const char *fromcode
  * @return				HRESULT.
  */
 template <typename _To_Type, typename _From_Type>
-HRESULT TryConvert(convert_context &context, const _From_Type &_from, _To_Type &_to) throw() {
+HRESULT TryConvert(convert_context &context, const _From_Type &_from, _To_Type &_to) {
 	try {
 		_to = context.convert_to<_To_Type>(_from);
 		return hrSuccess;
@@ -845,7 +819,7 @@ HRESULT TryConvert(convert_context &context, const _From_Type &_from, _To_Type &
  * @return				HRESULT.
  */
 template <typename _To_Type, typename _From_Type>
-HRESULT TryConvert(convert_context &context, const _From_Type &_from, size_t cbBytes, const char *fromcode, _To_Type &_to) throw() {
+HRESULT TryConvert(convert_context &context, const _From_Type &_from, size_t cbBytes, const char *fromcode, _To_Type &_to) {
 	try {
 		_to = context.convert_to<_To_Type>(_from, cbBytes, fromcode);
 		return hrSuccess;
