@@ -1,50 +1,24 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef mapi_memory_ptr_INCLUDED
 #define mapi_memory_ptr_INCLUDED
 
-#include "zcdefs.h"
+#include <zarafa/zcdefs.h>
 #include <utility>
 
 #ifdef free
@@ -52,7 +26,7 @@
 #endif
 
 template<typename _T>
-class mapi_memory_proxy _final {
+class mapi_memory_proxy _zcp_final {
 public:
 	typedef _T		value_type;
 	typedef _T**	pointerpointer;
@@ -67,7 +41,7 @@ private:
 };
 
 template <typename _T>
-class mapi_memory_ptr _final {
+class mapi_memory_ptr _zcp_final {
 public:
 	typedef _T						value_type;
 	typedef _T*						pointer;
@@ -85,10 +59,8 @@ public:
 
 	// Destructor
 	~mapi_memory_ptr() {
-		if (m_lpMemory) {
-			MAPIFreeBuffer(m_lpMemory);
-			m_lpMemory = NULL;
-		}
+		MAPIFreeBuffer(m_lpMemory);
+		m_lpMemory = NULL;
 	}
 
 
@@ -112,10 +84,8 @@ public:
 	
 	// Utility
 	void free() {
-		if (m_lpMemory) {
-			MAPIFreeBuffer(m_lpMemory);
-			m_lpMemory = NULL;
-		}
+		MAPIFreeBuffer(m_lpMemory);
+		m_lpMemory = NULL;
 	}
 
 	void swap(mapi_memory_ptr &other) {
@@ -150,11 +120,8 @@ public:
 	operator const void*() const { return m_lpMemory; }
 
 	proxy operator&() {
-		if (m_lpMemory) {
-			MAPIFreeBuffer(m_lpMemory);
-			m_lpMemory = NULL;
-		}
-
+		MAPIFreeBuffer(m_lpMemory);
+		m_lpMemory = NULL;
 		return proxy(&m_lpMemory);
 	}
 
@@ -165,11 +132,8 @@ public:
 	const _ZCPU as() const { return (_ZCPU)m_lpMemory; }
 
 	operator void**() {
-		if (m_lpMemory) {
-			MAPIFreeBuffer(m_lpMemory);
-			m_lpMemory = NULL;
-		}
-
+		MAPIFreeBuffer(m_lpMemory);
+		m_lpMemory = NULL;
 		return (void**)&m_lpMemory;
 	}
 
