@@ -1,44 +1,18 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef PLATFORM_LINUX_H
@@ -48,6 +22,7 @@
  * Functions and (type)definitions that are needed for the Linux platform
  *
  */
+#include <vector>
 #include <cstdio>
 #include <cstdlib>
 
@@ -81,12 +56,6 @@
   #include <unistd.h>
 #endif
 
-#ifndef HAVE_UUID_CREATE
-  #include <uuid/uuid.h>
-#else
-  #include <uuid.h>
-#endif
-
 #ifndef UNUSED_VAR
 #define UNUSED_VAR __attribute__((unused))
 #endif
@@ -620,8 +589,8 @@ class IEventSubscription : public IDispatch {
 };
 
 /* functions */
-bool operator!=(GUID, GUID);
-bool operator==(REFIID, GUID);
+bool operator!=(const GUID &, const GUID &);
+bool operator==(REFIID, const GUID &);
 HRESULT CoCreateGuid(LPGUID);
 
 void strupr(char *);
@@ -751,4 +720,6 @@ time_t GetProcessTime();
 #define z_tms tms
 #define z_times times
 
+std::vector<std::string> get_backtrace();
+
 #endif // PLATFORM_LINUX_H
