@@ -59,8 +59,10 @@ CONFIG = {
     'optimize_age': Config.ignore(),
     'optimize_start': Config.ignore(),
     'optimize_stop': Config.ignore(),
+    'run_as_user': Config.string(default="zarafa"),
+    'run_as_group': Config.string(default="zarafa"),
     'search_engine': Config.string(default='xapian'),
-    'server_bind_name': Config.string(default='file:///var/run/zarafa-search'),
+    'server_bind_name': Config.string(default='file:///var/run/zarafad/search.sock'),
     'ssl_private_key_file': Config.path(default=None, check=False), # XXX don't check when default=None?
     'ssl_certificate_file': Config.path(default=None, check=False),
     'term_cache_size': Config.size(default=64000000),
@@ -98,8 +100,8 @@ class SearchWorker(zarafa.Worker):
                     if cmd == 'PROPS':
                         response(conn, 'OK:'+' '.join(map(str, config['index_exclude_properties'])))
                         break
-                    if cmd == 'SYNCRUN': # XXX used from testset to trigger syncing
-                        time.sleep(5)
+                    if cmd == 'SYNCRUN': # wait for syncing to be up-to-date (used from testset)
+                        time.sleep(10) # XXX use multiprocessing signal
                         response(conn, 'OK:')
                         break
                     elif cmd == 'SCOPE':
@@ -108,7 +110,10 @@ class SearchWorker(zarafa.Worker):
                     elif cmd == 'FIND':
                         pos = data.find(':')
                         fields = map(int, data[:pos].split()[1:])
-                        terms = data[pos+1:].split()
+                        orig = data[pos+1:].lower()
+                        # Limit number of terms (32) so people do not
+                        # inadvertently DoS it if they paste prose.
+                        terms = plugin.extract_terms(orig)[:32]
                         if fields and terms:
                             fields_terms.append((fields, terms))
                         response(conn, 'OK:')
@@ -147,20 +152,22 @@ class IndexWorker(zarafa.Worker):
             changes = 0
             with log_exc(self.log):
                 (_, storeguid, folderid, reindex) = self.iqueue.get()
-                folder = zarafa.Folder(server.store(storeguid), folderid.decode('hex')) # XXX
-                self.log.info('syncing folder: %s %s' % (storeguid, folder.name))
-                importer = FolderImporter(server.guid, config, plugin, self.log)
-                state = db_get(state_db, folder.entryid) if not reindex else None
-                if state:
-                    self.log.info('found previous folder sync state: %s' % state)
-                t0 = time.time()
-                new_state = folder.sync(importer, state, log=self.log)
-                if new_state != state:
-                    plugin.commit()
-                    db_put(state_db, folder.entryid, new_state)
-                    self.log.info('saved folder sync state: %s' % new_state)
-                    changes = importer.changes + importer.deletes 
-                    self.log.info('syncing folder %s %s took %.2f seconds (%d changes, %d attachments)' % (storeguid, folder.name, time.time()-t0, changes, importer.attachments))
+                store = server.store(storeguid)
+                folder = zarafa.Folder(store, folderid.decode('hex')) # XXX
+                if store.public or folder not in (store.junk, store.outbox):
+                    self.log.info('syncing folder: %s %s' % (storeguid, folder.name))
+                    importer = FolderImporter(server.guid, config, plugin, self.log)
+                    state = db_get(state_db, folder.entryid) if not reindex else None
+                    if state:
+                        self.log.info('found previous folder sync state: %s' % state)
+                    t0 = time.time()
+                    new_state = folder.sync(importer, state, log=self.log)
+                    if new_state != state:
+                        plugin.commit()
+                        db_put(state_db, folder.entryid, new_state)
+                        self.log.info('saved folder sync state: %s' % new_state)
+                        changes = importer.changes + importer.deletes 
+                        self.log.info('syncing folder %s %s took %.2f seconds (%d changes, %d attachments)' % (storeguid, folder.name, time.time()-t0, changes, importer.attachments))
             self.oqueue.put(changes)
 
 class FolderImporter:
@@ -196,7 +203,10 @@ class FolderImporter:
                         self.attachments += 1
                         attach_text.append(plaintext.get(a, mimetype=a.mimetype, log=self.log))
                     attach_text.append(u' '+(a.filename or u''))
-            doc['mapi4096'] = item.body.text + u' ' + u' '.join(attach_text)
+            doc['mapi4096'] = item.body.text + u' ' + u' '.join(attach_text) # PR_BODY
+            doc['mapi3588'] = u' '.join([a.name + u' ' + a.email for a in item.to]) # PR_DISPLAY_TO
+            doc['mapi3587'] = u' '.join([a.name + u' ' + a.email for a in item.cc]) # PR_DISPLAY_CC
+            doc['mapi3586'] = u' '.join([a.name + u' ' + a.email for a in item.bcc]) # PR_DISPLAY_BCC
             doc['data'] = 'subject: %s\n' % item.subject
             db_put(self.mapping_db, item.sourcekey, '%s %s' % (storeid, item.folder.entryid)) # ICS doesn't remember which store a change belongs to..
             self.plugin.update(doc)
