@@ -47,6 +47,14 @@ class Plugin:
             if log: 
                 log.warn('could not open database: %s' % dbpath)
             
+    def extract_terms(self, text):
+        """ extract terms as if we are indexing """
+        doc = xapian.Document()
+        tg = xapian.TermGenerator()
+        tg.set_document(doc)
+        tg.index_text(text)
+        return [t.term.decode('utf-8') for t in doc.termlist()]
+
     def search(self, server_guid, store_guid, folder_ids, fields_terms, query, log):
         """ handle query; see links in the top for a description of the Xapian API """
 
@@ -83,7 +91,6 @@ class Plugin:
 
         self.deletes.append(doc)
 
-
     def commit(self):
         """ index pending documents; see links in the top for a description of the Xapian API """
 
@@ -94,7 +101,7 @@ class Plugin:
         try:
             # XXX we assume here that all data is from the same store
             doc = (self.data or self.deletes)[0]
-            with closing(self.open_db(doc['serverid'], doc['storeid'], writable=True)) as db:
+            with closing(self.open_db(doc['serverid'], doc['storeid'], writable=True, log=self.log)) as db:
                 termgenerator = xapian.TermGenerator()
                 termgenerator.set_database(db)
                 termgenerator.set_flags(termgenerator.FLAG_SPELLING)
