@@ -13,11 +13,12 @@ sub readconfig($) {
 		if ($_ =~ /^\s*[#!]/) {
 			next;
 		}
-		if ($_ =~ /\s*(\S+)\s*=\s*([^
-]+)/) {
+		if ($_ =~ /^\s*(\S+)\s*=\s*([^\r]+)\r?$/) {
+			my $idx = $1;
 			my $val = $2;
 			chomp($val);
-			$options{$1} = $val;
+			$val =~ s/\s+$//;
+			$options{$idx} = $val;
 		}
 	}
 	close(CFG);
@@ -41,18 +42,32 @@ if ($serveropt{user_plugin} ne "ldap" && $serveropt{user_plugin} ne "ldapms") {
 
 my %ldapopt = readconfig($serveropt{user_plugin_config});
 
-if (!defined($ldapopt{ldap_user_sendas_attribute_type}) && defined($ldapopt{ldap_sendas_attribute_type})) { 
-	$ldapopt{ldap_user_sendas_attribute_type} = $ldapopt{ldap_sendas_attribute_type};
+if (!defined($ldapopt{ldap_sendas_attribute_type}) && defined($ldapopt{ldap_user_sendas_attribute_type})) { 
+	$ldapopt{ldap_sendas_attribute_type} = $ldapopt{ldap_user_sendas_attribute_type};
 }
 
-if (!defined($ldapopt{ldap_user_sendas_relation_attribute}) && defined($ldapopt{ldap_sendas_relation_attribute})) {
-	$ldapopt{ldap_user_sendas_relation_attribute} = $ldapopt{ldap_sendas_relation_attribute};
+if (!defined($ldapopt{ldap_sendas_relation_attribute}) && defined($ldapopt{ldap_user_sendas_relation_attribute})) {
+	$ldapopt{ldap_sendas_relation_attribute} = $ldapopt{ldap_user_sendas_relation_attribute};
 }
 
-if (!defined($ldapopt{ldap_user_sendas_attribute}) && defined($ldapopt{ldap_sendas_attribute})) {
-	$ldapopt{ldap_user_sendas_attribute} = $ldapopt{ldap_sendas_attribute};
+if (!defined($ldapopt{ldap_sendas_attribute}) && defined($ldapopt{ldap_user_sendas_attribute})) {
+	$ldapopt{ldap_sendas_attribute} = $ldapopt{ldap_user_sendas_attribute};
 }
 
+# sanity check
+if (!defined($ldapopt{ldap_sendas_attribute}) || !defined($ldapopt{ldap_sendas_attribute_type}) || !defined($ldapopt{ldap_sendas_relation_attribute})) {
+	print "Some of the required attributes are not set.\nPlease check the following values (or alias config names):\n";
+	if (!defined($ldapopt{ldap_sendas_attribute})) {
+		print "ldap_sendas_attribute\n";
+	}
+	if (!defined($ldapopt{ldap_sendas_attribute_type})) {
+		print "ldap_sendas_attribute_type\n";
+	}
+	if (!defined($ldapopt{ldap_sendas_relation_attribute})) {
+		print "ldap_sendas_relation_attribute\n";
+	}
+	exit(0);
+}
 
 my ($ldap_search_base, $ldap_search_filter);
 
@@ -74,10 +89,10 @@ $msg->code && die $msg->error;
 
 my (%u2dn, %dn2u);
 my $match = "dn";
-if ($ldapopt{ldap_user_sendas_attribute_type} ne "dn") {
+if ($ldapopt{ldap_sendas_attribute_type} ne "dn") {
 	print "Looking up all users...\n";
-	if (defined($ldapopt{ldap_user_sendas_relation_attribute}) && $ldapopt{ldap_user_sendas_relation_attribute} ne "") {
-		$match = $ldapopt{ldap_user_sendas_relation_attribute};
+	if (defined($ldapopt{ldap_sendas_relation_attribute}) && $ldapopt{ldap_sendas_relation_attribute} ne "") {
+		$match = $ldapopt{ldap_sendas_relation_attribute};
 	} else {
 		$match = $ldapopt{ldap_user_unique_attribute};
 	}
@@ -96,13 +111,13 @@ if ($ldapopt{ldap_user_sendas_attribute_type} ne "dn") {
 
 print "Finding send-as settings...\n";
 $msg = $ldap->search(base => $ldap_search_base, filter => $ldap_search_filter, scope => $ldapopt{ldap_user_scope},
-					 attrs => [$ldapopt{ldap_user_sendas_attribute}]);
+					 attrs => [$ldapopt{ldap_sendas_attribute}]);
 $msg->code && die $msg->error;
 
 my $users = $msg->as_struct();
 my $attrUnique = lc($ldapopt{ldap_user_unique_attribute});
 my $attrName = lc($ldapopt{ldap_loginname_attribute});
-my $attrSendas = lc($ldapopt{ldap_user_sendas_attribute});
+my $attrSendas = lc($ldapopt{ldap_sendas_attribute});
 
 my %modify;
 my %remove;
@@ -132,12 +147,19 @@ foreach (keys %$users) {
 	}
 }
 
+print "\nApply above changes to ldap? [y] ";
+my $ans = <STDIN>;
+chomp($ans);
+if (! ($ans eq "" || $ans =~ m/y.*/i)) {
+	exit(0);
+}
+
 print "Removing old send-as settings...\n";
 foreach (keys %remove) {
 	my $dn = $_;
 
 	$msg = $ldap->modify($dn, delete => [ $attrSendas ] );
-	$msg->code && print $msg->error."\n";
+	$msg->code && print $msg->error." for ".$dn."\n";
 }
 
 print "Setting new send-as settings...\n";
@@ -145,7 +167,7 @@ foreach (keys %modify) {
 	my $dn = $_;
 
 	$msg = $ldap->modify($dn, replace => { $attrSendas => [ @{$modify{$dn}} ] });
-	$msg->code && print $msg->error."\n";
+	$msg->code && print $msg->error." for ".$dn."\n";
 }
 
 $ldap->unbind();
