@@ -23,3 +23,5 @@ if [ -z "${ZARAFA_USER}" -a -z "${ZARAFA_STOREGUID}" ] ; then
 fi
 
 find ${ZARAFA_USER_SCRIPTS} -maxdepth 1 -type f -perm -u=x -and ! -name \*~ -and ! -name \#\* -exec {} \;
+cd "$ZARAFA_USER_SCRIPTS"
+find "${ZARAFA_USER_SCRIPTS}" -maxdepth 1 -type f -perm -u=x -not -name \*~ -not -name \#\* -not -name \*.rpm\* -not -name \*.bak -not -name \*.old -exec {} \;
